==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/cmq/v20190304/models/Filter.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cmq.v20190304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Filter extends AbstractModel{

    /**
    * 过滤参数的名字
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
    * 数值
    */
    @SerializedName("Values")
    @Expose
    private String [] Values;

    /**
     * Get 过滤参数的名字 
     * @return Name 过滤参数的名字
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 过滤参数的名字
     * @param Name 过滤参数的名字
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * Get 数值 
     * @return Values 数值
     */
    public String [] getValues() {
        return this.Values;
    }

    /**
     * Set 数值
     * @param Values 数值
     */
    public void setValues(String [] Values) {
        this.Values = Values;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);
        this.setParamArraySimple(map, prefix + "Values.", this.Values);

    }
}

==> tencentcloud-sdk-java-3.1.433-sources.jar: com/tencentcloudapi/cmq/v20190304/models/Filter.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cmq.v20190304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Filter extends AbstractModel{

    /**
    * 过滤参数的名字
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
    * 数值
    */
    @SerializedName("Values")
    @Expose
    private String [] Values;

    /**
     * Get 过滤参数的名字 
     * @return Name 过滤参数的名字
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 过滤参数的名字
     * @param Name 过滤参数的名字
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * Get 数值 
     * @return Values 数值
     */
    public String [] getValues() {
        return this.Values;
    }

    /**
     * Set 数值
     * @param Values 数值
     */
    public void setValues(String [] Values) {
        this.Values = Values;
    }

    public Filter() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Filter(Filter source) {
        if (source.Name != null) {
            this.Name = new String(source.Name);
        }
        if (source.Values != null) {
            this.Values = new String[source.Values.length];
            for (int i = 0; i < source.Values.length; i++) {
                this.Values[i] = new String(source.Values[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);
        this.setParamArraySimple(map, prefix + "Values.", this.Values);

    }
}
